/*
 * SonarQube Java
 * Copyright (C) 2012-2021 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.java.se.checks;

import org.junit.jupiter.api.Test;
import org.sonar.java.TestUtils;
import org.sonar.java.se.SETestUtils;
import org.sonar.java.testing.CheckVerifier;

class XxeProcessingCheckTest {

  @Test
  void Xml_input_factory() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_XmlInputFactory.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

  @Test
  void document_builder_factory() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_DocumentBuilderFactory.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

  @Test
  void sax_parser() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_SaxParser.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

  @Test
  void schema_factory() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_SchemaFactory_Validator.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

  @Test
  void transformer_factory() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_TransformerFactory.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

  @Test
  void xml_reader() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_XmlReader.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

  @Test
  void sax_builder() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_SaxBuilder.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

  @Test
  void sax_reader() {
    CheckVerifier.newVerifier()
      .onFile(TestUtils.testSourcesPath("symbolicexecution/checks/S2755_XxeProcessingCheck_SaxReader.java"))
      .withCheck(new XxeProcessingCheck())
      .withClassPath(SETestUtils.CLASS_PATH)
      .verifyIssues();
  }

}
